pecos.qeclib.steane
===================

.. automodule:: pecos.qeclib.steane



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.qeclib.steane.decoders
   pecos.qeclib.steane.gates_sq
   pecos.qeclib.steane.gates_tq
   pecos.qeclib.steane.meas
   pecos.qeclib.steane.preps
   pecos.qeclib.steane.qec
   pecos.qeclib.steane.steane_class
   pecos.qeclib.steane.syn_extract
